// Copyright 2018 JDCLOUD.COM
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// NOTE: This class is auto generated by the jdcloud code generator program.

package models


type RouteTable struct {

    /* 路由表ID (Optional) */
    RouteTableId string `json:"routeTableId"`

    /* 路由表名称，只允许输入中文、数字、大小写字母、英文下划线“_”及中划线“-”，不允许为空且不超过32字符。 (Optional) */
    RouteTableName string `json:"routeTableName"`

    /* 路由表类型，default：默认路由表，custom：自定义路由表 (Optional) */
    RouteTableType string `json:"routeTableType"`

    /* 路由表描述信息，允许输入UTF-8编码下的全部字符，不超过256字符。 (Optional) */
    Description string `json:"description"`

    /* 私有网络ID (Optional) */
    VpcId string `json:"vpcId"`

    /* 路由表规则信息 (Optional) */
    RouteTableRules []RouteTableRule `json:"routeTableRules"`

    /* 路由表绑定的子网列表 (Optional) */
    SubnetIds []string `json:"subnetIds"`

    /* 路由表创建时间 (Optional) */
    CreatedTime string `json:"createdTime"`
}
